==> pdapi-1.20.4+1.0.1-sources.jar: ml/pluto7073/pdapi/addition/action/DealDamageAction.java <==
package ml.pluto7073.pdapi.addition.action;

import com.google.gson.JsonObject;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2540;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import net.minecraft.class_8110;

public class DealDamageAction implements OnDrinkAction {

    private final float amount;
    private final class_5321<class_8110> source;

    public DealDamageAction(float amount, class_5321<class_8110> source) {
        this.amount = amount;
        this.source = source;
    }

    @Override
    public void onDrink(class_1799 stack, class_1937 level, class_1309 user) {
        user.method_5643(user.method_48923().method_48795(source), amount);
    }

    @Override
    public OnDrinkSerializer<?> serializer() {
        return OnDrinkSerializers.DEAL_DAMAGE;
    }

    public static class Serializer implements OnDrinkSerializer<DealDamageAction> {

        public static final Codec<DealDamageAction> CODEC = RecordCodecBuilder.create(instance ->
                instance.group(Codec.FLOAT.fieldOf("amount").forGetter(action -> action.amount),
                        class_5321.method_39154(class_7924.field_42534).fieldOf("source").forGetter(action -> action.source))
                        .apply(instance, DealDamageAction::new));

        @Override
        public Codec<DealDamageAction> codec() {
            return CODEC;
        }

        @Override
        public DealDamageAction fromNetwork(class_2540 buf) {
            float amount = buf.readFloat();
            class_5321<class_8110> source = buf.method_44112(class_7924.field_42534);
            return new DealDamageAction(amount, source);
        }

        @Override
        public void toNetwork(class_2540 buf, DealDamageAction action) {
            buf.method_52941(action.amount);
            buf.method_44116(action.source);
        }
    }

}

==> pdapi-1.20.6+2.0.2-sources.jar: ml/pluto7073/pdapi/addition/action/DealDamageAction.java <==
package ml.pluto7073.pdapi.addition.action;

import com.google.gson.JsonObject;
import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2540;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import net.minecraft.class_8110;
import net.minecraft.class_9129;
import net.minecraft.class_9139;

public class DealDamageAction implements OnDrinkAction {

    private final float amount;
    private final class_5321<class_8110> source;

    public DealDamageAction(float amount, class_5321<class_8110> source) {
        this.amount = amount;
        this.source = source;
    }

    @Override
    public void onDrink(class_1799 stack, class_1937 level, class_1309 user) {
        user.method_5643(user.method_48923().method_48795(source), amount);
    }

    @Override
    public OnDrinkSerializer<?> serializer() {
        return OnDrinkSerializers.DEAL_DAMAGE;
    }

    public static class Serializer implements OnDrinkSerializer<DealDamageAction> {

        public static final MapCodec<DealDamageAction> CODEC = RecordCodecBuilder.mapCodec(instance ->
                instance.group(Codec.FLOAT.fieldOf("amount").forGetter(action -> action.amount),
                        class_5321.method_39154(class_7924.field_42534).fieldOf("source").forGetter(action -> action.source))
                        .apply(instance, DealDamageAction::new));
        public static final class_9139<class_9129, DealDamageAction> STREAM_CODEC =
                class_9139.method_56437(Serializer::toNetwork, Serializer::fromNetwork);

        @Override
        public MapCodec<DealDamageAction> codec() {
            return CODEC;
        }

        @Override
        public class_9139<class_9129, DealDamageAction> streamCodec() {
            return STREAM_CODEC;
        }

        public static DealDamageAction fromNetwork(class_2540 buf) {
            float amount = buf.readFloat();
            class_5321<class_8110> source = buf.method_44112(class_7924.field_42534);
            return new DealDamageAction(amount, source);
        }

        public static void toNetwork(class_2540 buf, DealDamageAction action) {
            buf.method_52941(action.amount);
            buf.method_44116(action.source);
        }
    }

}
